from enum import Enum


class ListJobsResponse200ItemType1RawFlowFailureModuleSuspendUserGroupsRequiredType0Type(str, Enum):
    STATIC = "static"

    def __str__(self) -> str:
        return str(self.value)
